Skip to contents

importQFeatures is a simple graphical interface to import bulk and single-cell proteomics data. The app uses the readQFeatures function from the QFeatures package to convert simple tables (single or multiple, CSV or TSV) to a QFeatures object. The app allows users to convert tables to a QFeatures object.

Usage

importQFeatures(colData = NULL, assayData = NULL, maxSize = 1000)

Arguments

colData

A data frame that contains the sample table.

assayData

A data frame that contains the input table.

maxSize

An integer that changes the shiny.maxRequestSize value, in MB.

Value

The "importQFeatures" Shiny app object.

Examples

library(QFeaturesGUI)

data("sampleTable")
data("inputTable")
app <- importQFeatures(colData = sampleTable, assayData = inputTable, maxSize = 100)

if (interactive()) {
    shiny::runApp(app)
}