A data frame with 48 observations on the following 6 variables.
Set: a character vector
Channel: a character vector
SampleType: a character vector
lcbatch: a character vector
sortday: a character vector
digest: a character vector
Usage
data("sampleTable")Details
The dataset is a subset of the SCoPE2 dataset (version 2, Specht
et al. 2019,
BioRXiv). The
input files batch.csv and annotation.csv were downloaded from a
Google Drive repository.
The two files were loaded and the column names were adapted for
consistency with mqScpData table (see ?mqScpData). The two
tables were filtered to contain only sets present in mqScpData.
The tables were then merged based on the run ID, hence merging the
sample annotation and the batch annotation. Finally, annotation
for the blank run was added manually. The data is stored as a
data.frame.